@@ -1,7 +1,7 @@
 ;;; magik-mode.el --- Emacs major mode for Smallworld Magik files
 
-;; Package-Version: 0.5.5
-;; Package-Revision: 0ccfffef5308
+;; Package-Version: 20251006.1327
+;; Package-Revision: 069a1d630f63
 ;; Package-Requires: ((emacs "24.4") (compat "28.1") (yasnippet "0.14.0"))
 ;; URL: https://github.com/roadrunner1776/magik
 ;; Keywords: languages
@@ -30,7 +30,8 @@
   (defvar msb-menu-cond)
   (require 'magik-indent)
   (require 'magik-electric)
-  (require 'magik-pragma))
+  (require 'magik-pragma)
+  (require 'magik-utils))
 
 (require 'compat)
 (require 'imenu)
@@ -107,7 +108,9 @@ concrete implementations."
                imenu-syntax-alist '((?_ . "w"))
                outline-regexp "\\(^\\(_abstract +\\|\\)\\(_private +\\|\\)\\(_iter +\\|\\)_method.*\\|.*\.\\(def_property\\|add_child\\)\\|.*\.define_\\(shared_variable\\|shared_constant\\|slot_access\\|slot_externally_\\(read\\|writ\\)able\\|property\\|interface\\|method_signature\\).*\\|^\\(\t*#+\>[^>]\\|def_\\(slotted\\|indexed\\)_exemplar\\|def_mixin\\|#% text_encoding\\|_global\\|read_\\(message\\|translator\\)_patch\\).*\\)")
 
-  (when magik-auto-abbrevs (abbrev-mode 1))
+  (when magik-auto-abbrevs
+    (abbrev-mode t)
+    (yas-minor-mode t))
 
   (imenu-add-menubar-index))
 
@@ -1055,9 +1058,9 @@ e.g. (magik-function \"system.test\" \"file\" \\='unset 4) returns the string
 Argument CMD ...
 Optional argument ARGS ..."
 
-                                        ;process arg types: nil, string, other...
+  ;; process arg types: nil, string, other...
   (setq args (mapcar 'magik-function-convert args))
-                                        ;bring the command together adding commas between the arguments
+  ;; bring the command together adding commas between the arguments
   (concat cmd "(" (mapconcat 'identity args ", ") ")\n"))
 
 (defun magik-gis-error-goto (&optional gis)
@@ -1565,13 +1568,13 @@ With a prefix arg, ask user for GIS buffer to use."
                                             'magik-session-buffer-alist-prefix-function))
   (barf-if-no-gis buffer)
 
-  (if (equal (magik-utils-curr-word) "")
+  (if (equal (magik-utils--current-word) "")
       (message "Doing a completion on the empty string would take too long")
-    (if (<= (length (magik-utils-curr-word)) 2)
+    (if (<= (length (magik-utils--current-word)) 2)
         (message "Symbol is already complete or is too short."))
     (process-send-string
      (get-buffer-process buffer)
-     (concat "symbol_table.emacs_write_completions(\"" (magik-utils-curr-word) "\")\n$\n"))))
+     (concat "symbol_table.emacs_write_completions(\"" (magik-utils--current-word) "\")\n$\n"))))
 
 (defun magik-compare-methods (ignore-whitespace)
   "Compare Methods in two windows using \\[compare-windows].
@@ -1872,6 +1875,7 @@ Translate it and the closing bracket into the new \"{...}\" notation."
 Prevents expansion inside strings and comments."
   (interactive)
   (when (or (magik--in-string-or-comment-p)
+            (not yas-minor-mode)
             (not (yas-expand)))
     (self-insert-command 1)))
 
